#! /bin/bash

PACKAGE_NAME="printer-driver-bisheng-brother-dcp-j4110dw-printer"
PACKAGE_VERSION="2.0.1"
PRINTER_NAME=( "Brother DCP-J4110DW Printer" "Brother DCP-J4210N Printer" "Brother MFC-J2310 Printer" "Brother MFC-J4310DW Printer" "Brother MFC-J4410DW Printer" "Brother MFC-J2510 Printer" "Brother MFC-J4510DW Printer" "Brother MFC-J4510N Printer" "Brother MFC-J4610DW Printer" "Brother MFC-J4710DW Printer" "Brother MFC-J4910CDW Printer" "Brother MFC-J4305DW Printer" "Brother MFC-J4315DW Printer" "Brother MFC-J4405DW Printer" "Brother MFC-J4415DW Printer" "Brother MFC-J4505DW Printer" "Brother MFC-J4515DW Printer" "Brother MFC-J4605DW Printer" "Brother MFC-J4615DW Printer" "Brother DCP-J4215N Printer" "Brother MFC-J4810DN Printer" )

CONTAINER_PATH="$HOME/.deepinwine/$PACKAGE_NAME"
OPT_PATH="/opt/deepinwine/printer_drv/$PACKAGE_NAME"
WINEBIN="bisheng"
REGDIR="reg"
FILEDIR="files"

PRINTER_C=$1
found=0
for name in "${PRINTER_NAME[@]}"; do
    if [ "$PRINTER_C" = "$name" ]; then
        found=1
        break
    fi
done

if [ $found -eq 0 ]; then
    echo "printer $PRINTER_C not found"
    exit 0
fi

if [ -z "$PACKAGE_NAME" -o ! -d "$OPT_PATH" ]; then
    exit 1
fi

if [ -d "$CONTAINER_PATH" ]; then
    # compare version
    if [ ! -f "$CONTAINER_PATH/VERSION" ] || [ "$(cat "$CONTAINER_PATH/VERSION")" != "$PACKAGE_VERSION" ]; then
        rm -rf "$CONTAINER_PATH"
    fi
fi

WININI="$CONTAINER_PATH/drive_c/windows/win.ini"
if [ -f  $WININI ]; then
    grep -q "^$PRINTER_C=winerp.drv,USB" "$WININI" && exit 0
fi

if [ -d "$OPT_PATH/$REGDIR" ]; then
    find "$OPT_PATH/$REGDIR" -type f -regex ".*\.reg" | while read file; do
        WINEPREFIX=$CONTAINER_PATH $WINEBIN regedit "$file"
    done
fi

if [ -d "$OPT_PATH/$FILEDIR" ]; then
    find "$OPT_PATH/$FILEDIR" -not -type d | while read file; do
        path="$CONTAINER_PATH/drive_c/${file#*$FILEDIR/}"
        dir="${path%/*}"
        mkdir -p "$dir"
        cp -d "$file" "$path"
    done
fi

if [ -f "$WININI" ]; then
    grep -q "^\[devices\]" "$WININI" || sed -i -e "$ a [devices]" "$WININI"
    grep -q "^\[PrinterPorts\]" "$WININI" || sed -i -e "$ a [PrinterPorts]" "$WININI"
    sed -i -e "/^\[devices\]/a $PRINTER_C=winerp.drv,USB" "$WININI"
    sed -i -e "/^\[PrinterPorts\]/a $PRINTER_C=winerp.drv,USB,15,45" "$WININI"
fi

WINESERVER_RUNNING=1
WINESERVER_FINDNUM=0
while [ $WINESERVER_RUNNING -eq 1 ]
do
        WINESERVER_PATH=`ps -aux|grep wineserver|grep -v grep`
        if [ "$WINESERVER_PATH" = "" ] || [ $WINESERVER_FINDNUM -eq 3 ]; then
                WINESERVER_RUNNING=0
        else
                let WINESERVER_FINDNUM+=1
                sleep 1
        fi
done

echo "$PACKAGE_VERSION" > "$CONTAINER_PATH/VERSION"
echo "$PRINTER_NAME" > "$CONTAINER_PATH/name.log"
